THE RANCHING FRONTIER IN THE CANADIAN WEST: 1874-1905 

David H. Breen 

     The myth, stereotype and fiction surrounding this phase of western development greatly compound the usual difficulties of historical assessment and often lead one away from the essential core. We may begin, perhaps, by recognizing that ranching is a form of land use - it is an arid land adaptation. In the North American context, ranching is one of several competing land use alternatives in drier regions, and in the long run, the persistence of ranching compared to other patterns of land use is determined by return on investment. If grain growing, for example, offers a greater per acre return, then the ranching industry predictably contracts. Ranching is not a subsistence occupation. Cattle ranching, as it developed in the early 1880's, was strictly a business operation. In the sense that it developed to supply growing urban markets, it was a product of the specialization resulting from the industrial revolution. The ranching industry depends on the presence of large urban markets as well as a massive processing and transportation infrastructure to link producer and consumer. 

     Beyond this basic awareness of the economic imperative, rests an obvious continental perspective that must be acknowledged in any consideration of the ranching frontier in Canada. To what extent, in the Territorial period (1870-1905) at least, can the international boundary be ignored? Several scholars argue that the ranching frontier in Canada was in form and spirit the most "American" of all Canadian frontiers. While we see obvious unities of time, geography and economic organization we can challenge the usual ascription of social and cultural homogeneity, which assumes that the population on the Canadian side was largely of American origin. 

     In addition to assessing how the ranching frontier in Canada relates to the larger North American ranching scene, the ranching industry must also be considered in the national perspective. That is, how do the cattlemen and their industry fit into the opening and development of the Canadian West? 

     The development of the cattle industry in the Canadian southwest was coincident with that of the northwestern American plains. In the mid 1870's, as stockmen began to move into the Powder River and Big Horn country of northern Wyoming, and from the sheltered valleys of western Montana onto the eastern plains, cattlemen were also moving small herds into the foothill country of the southwestern corner of the Canadian Northwest Territories which then included Alberta and Saskatchewan. That movement of cattle into the Canadian foothill country is hardly surprising. For the region provided a potentially excellent grazing area. The region's unique climatic feature, the "chinook", brought warm dry winter winds which regularly melted the snow and exposed the grass for, winter pasture. The stock raising possibilities of the southwest were further enhanced by the highly nutritious short grass vegetation, by the numerous coulees which furnished natural shelter, and by the large number of streams suitable for stock-watering. 

     The North-West Mounted Police, coming west as they did in 1874, just at the outset of the rapid and vast expansion of the ranching frontier south of the border, ensured that the northern boundary of the cattle kingdom would fall several hundred miles inside Canadian territory. The police provided a limited local market about which a small scale indigenous industry could evolve, and certain Montana and Hudson's Bay Company traders, who had long recognized the territory's ranching potential, were quick to take advantage. Even more important, the presence and eventual success of the police in 1877 in negotiating with the powertul Blackfoot Confederacy the surrender of their aboriginal land title, as embodied in Indian Treaty Number Seven, promised the security that open grazing required. This meant that the cattlemen pushing into the foothill valleys in the later seventies did not fight the Indians to gain possession as was often the pattern in the American West. Furthermore, the government's treaty obligation to supply the Indians with beef as the buffalo declined, added the further inducement of an expanded market. 

     Members of the force witnessed the arrival of the first small herds in the southwest between 1874 and 1876, and many especially those from the stock raising districts of Quebec's Eastern Townships, recognized the unequaled opportunities at hand and determined to go into the cattle business when their three-year enlistment terms expired. Thus in 1877, as the first enlistment contracts came due, and over the next twenty years, dozens of men and officers took their discharge and remained to ranch in the West. It was mainly about this core that the ranching industry in the Canadian West developed. The police exerted a profound long-term influence on the region's social development and, in particular, strengthened the community's law and order ethos. 

     The police were also largely responsible for drawing the attention of other easterners to the country's ranching potential, and the ranchers' fraternity was soon augmented by others from the Townships and rural Ontario who further strengthened the community's eastward and Canadian orientation. Added to these Canadians was a host of immigrants from the British Isles who very often wrote "gentleman" under the heading "previous occupation" on their homestead applications. These prospective ranchers invariably possessed sufficient captial to establish ranches of their own and were drawn generally from the ranks of the lesser landed gentry and military families. The English character of the ranching community and the presence of so many Englishmen "of good family" was consistently reported by vistors to the region before the turn of the century. 

     Though some of the first ranchers in the Canadian southwest were American, before 1900 they were always a small minority, and by virtue of their small number, the contribution made by this group to the evolving social and political environment was small. By 1890 even most of the cowboys were of Canadian or British origin. Clearly, most of the ranchers who came to the southwest comprised a class collectively very different from the American ranch community and distinct from the western farm population with whom they are often equated. 

     Viewing society in the Canadian ranch country before 1900, we see not a community of innovators seeking a release from the restraints of traditional ways, but, rather, a society vigorously attempting to recreate the kind of community its members had known and found congenial elsewhere. And the economic structure of the cattle industry was especially well-suited to the defence of traditional ways. First, the character of the industry, itself, had largely determined the class base from which the population was drawn. Stock raising, unlike farming, demanded a substantial initial capital investment and therefore tended to eliminate those of lesser means. Second, once the proprietor had established his ranch, the operational structure was particularly suitable for the support of the English country estate ethos. Cattle ranching permitted the retention of the manager-employer relationship as well as a leisured life style, which perpetuated an imported social system that helped to set the ranch community apart from the general social development of the agrarian frontier. 

     Until 1881 the Canadian cattle kingdom had been mainly the preserve of the small rancher dependent upon a limited local market. The prerequisite for more extensive development was obviously an export market, and this, in turn, depended on the use of a transcontinental railway. The launching of the new Canadian Pacific Railway in 1880, coupled with the advantageous British government decision a few months earlier to impose an embargo on live cattle from the United States suddenly presented the possibility of huge export sales and therefore greatly stimulated eastern interest in the grazing region. 

   This quickly developing interest in the Canadian ranch country was part of a continent-wide phenomenon. Railroads had already penetrated the American West and suddenly cheap western beef gained access to high-price markets in the eastern United States and Europe. The arithmetic of profit was blatantly straightforward; a good calf worth five dollars at birth in the west could be fed on almost free grass and would bring forty to sixty dollars in the east when ready for market three or four years later. Popular and investment journals were soon filled with reports from western ranchers claiming profits of thirty to to one hundred percent per year. By 1879 the great cattle boom or the "Beef Bonanza", as it was known, was underway. Ranching fever developed simultaneously in Canada as Canadian captialists discovered that a comparable grazing area, already proven by small stockmen, existed in their own west. The Canadian press joined that of the United States and Great Britain to proclaim this new Eldorado, and in Ottawa, a host of newly formed cattle companies jockied for preferred western lands. 

     Before investing their capital in western ranches, anxious Canadian investors pressed the government to establish a formal system of land tenure. The American system of "range rights", a form of squatter sovereignty recognized by custom, that gave the stockmen first grazing a herd in a particular area a kind of prescriptive but extralegal right to that range, seemed much too tenuous to potential Canadian investors. This apprehension was eased by the comprehensive lease system that emerged from discussions between Prime Minister John A. Macdonald, who served also as minister of the interior and Senator Matthew H. Cochrane, who was perhaps the most prominent stock-breeder in the country and on whose lead other hastily organized ranching companies stood in line for government consideration. Under the lease terms, presented in December 1881, grazing leases of up to 100,000 acres were offered for twenty-one years at the rate of ten dollars per 1,000 acres - or one cent per acre per year. In light of later developments, perhaps the most significant feature of the new lease policy was the provision that excluded all except the lessee from the right of immediate homestead entry. 

     The lease system was the foundation upon which the early ranching empire in Canada was built and it meant that the Canadian range developed in a manner significantly different from the American pattern. By leasing the public domain rather than allowing it to be used as common pasture, the Canadian government maintained a much more direct control of land use, and by establishing a clear basis of legal ownership, helped prevent the range wars that occasionally developed in the American West among ranchers disputing one another's rights to a particular range. It also forestalled the would-be settler. Those who had the temerity to squat on the extensive leaseholds did so only at the sufferance of the leaseholder and more often than not were summarily evicted by the rancher and his cowhands or by the police. While the lease system did counter some of the more obvious difficulties characteristic of the American system and while it had much economic and legal merit, it nonetheless initiated a struggle between farmer and rancher that was to plague the federal authorities for the next three decades. 

     The cattle company era - or as some have termed it, the ranching frontier's golden age - began with the government's 1881 lease policy. Very soon, many of the purely speculative ranching ventures were absorbed in the aggressive competition for territory, so that by 1884 the cattle country was dominated by about a dozen large companies, some with holdings running to hundreds of thousands of acres. The directorship lists of these big cattle companies read like a "Who's Who" in the Canadian business world of the day, and these intimate metropolitan links provided the stockmen with a most effective and often preferred political voice. The regional hegemony of these big operators until the mid `nineties influenced extra-regional contacts. Power they gained outside their home territory in turn strengthened the local control they exercised through the cattlemen's association. 

     The rancher's cattle wandered freely and largely unattended over the open range and the need to protect this scattered and exposed property, which represented nearly all his capital investment, was uppermost in the owner's mind. To this end, the cattlemen organized to enforce local regulations concerning brands and branding, roundup times and organization, the control of bulls on the range, and the ownership of unbranded cattle, or "mavericks" as they were known to cattlemen. Control of the cattlemen's association, in effect, allowed the larger ranchers to more or less dictate the manner in which the industry would be conducted locally, and at the same time provided a useful platform from which the large stock growers could claim to speak as the legitimate and official spokesmen of the cattle industry to the world outside. 

     A fundamental difference between the stockman and his farming neighbors is reflected in the basic nature of their respective organizations. Unlike the western farmer, the stock-grower did not seek cooperative effort to remedy the wants growing out of isolation such as roads, schools, and social amenities, all of which increased land values. His motivation towards organization came from the reverse reason: the stock-grower organized not because he was isolated but because his isolation was threatened. In this sense his organization is unique to the western experience. Settlement was a potential threat to his range and his rewards were potentially the greatest when his isolation was most complete. 

     The encompassing strength of the "cattle compact" was manifest in a number of ways: in their ability to secure desired quarantine legislation, stock import restrictions, expanded police patrols, and the removal from their region of the "odious" sheepman whose Rocks threatened grazing competition. The ranchers' main pre-occupation, however, was the home-steader, or the "sod-buster" as he was more uncharitably known to the cattlemen, and in this contest the cattlemen's impressive resources were taxed to the limit. 

     Homesteaders who began arriving in increasing numbers by the middle `eighties, were confronted with a very sparsely settled countryside in which most of the suitable homestead land was not open for settlement. Faced with this situation, most prospective settlers continued to the better-watered lands north of Calgary. A minority, who were no doubt aware of the well-publicized financial success of ranching operations and who probably had a mind to become small-scale stock raisers themselves, remained to squat on the extensive leaseholds. The cattlemen were obviously not anxious to see farmers' barbed-wire fences and plowed furrows encroach upon their great grazing leases, and realized that if even a few squatters were allowed to remain they would soon be joined by others. The ranchers, therefore, maintained a posture of open hostility and did their best to have squatters summarily removed whenever they appeared. By 1885 animosity between the ranchers and prospective settlers reached a flash point. That spring a group of harried settlers meeting on a farm just south of Calgary threatened to join the Indians and Metis in rebellion if the government did not open homestead land in the vicinity. The chairman of the gathering, Sam Livingston, observed that between "government reserves, leases, school lands, and Hudson's Bay lands, a man was unable to find a spot to settle," and if one did settle he was certain "to be chased by someone, either by the police, land agents, or government officials of some kind." In Livingston's view the current situation left no alternative but to resort to arms. Rather than be "driven out" like some forty or fifty other settlers with whom he claimed personal acquaintance, he announced his determination to defend his claim with his Winchester. 

     By 1886 it was apparent to the federal government and to the cattlemen that the growing popular clamour against the lease system required some accommodation. The Department of the Interior therefore canceled a number of the unstocked speculative leases in the Calgary area and announced that leases granted henceforth would no longer contain the offensive "no-settlement" clause. In agreeing to accept this change, however, the stockmen were successful in extracting from the government its promise to establish a system of public water reservations from which settlement would be restricted. If the range could not be controlled through a system of closed leases, it was apparent to the cattlemen that the same ends might be gained even more effectively through control of the region's springs, streams, and river fronts. 

     The government's new lease policy and the cancellation of certain speculative leases brought only brief tranquility to the Canadian range. For the next five years the Bow River valley remained in a state of constant turmoil and the Department of the Interior was the recipient of petitions, threats and counterthreats from the contending parties. At the same time further south, the large ranch companies continued to police their leaseholds with rigorous vigilance. One British-owned ranch company, the Walrond, pursued a particularly aggressive policy towards would-be settlers and an arsonist's attack on Walrond property in 1892 eventually brought the whole matter before Parliament. The incident which had caused the incendiary outbreak and which set the squatters and the ranch companies on a collision course seems to have originated in the eviction of several squatters from their homes in midwinter. The ranch manager warned that his men would prevent trespassing and predicted that a clash with the squatters was imminent unless the government firmly supported the ranchers' legal rights. The squatters were equally determined. The police sinperintendant, Colonel S.B. Steele, warned his superior of the delicate situation and predicted that any further evictions would be followed by additional reprisals. 

     The federal government found itself in a dilemma. Public opinion supported by the Opposition inside Parliament was plainly hostile to the cattlemen. At the same time the ruling Conservatives had little desire to antagonize a group so initimately represented within its own membership. But as the tide of public criticism advanced and as the government was repeatedly called to account for the apparent disregard of its own longstanding commitment to western settlement, it became ever more politically expedient to arrive at a compromise with the ranching interests. In conclave with the minister of the interior in early 1892, the ranchers' deputation was compelled, therefore, to accept a four-year notice of cancellation of all of the old "closed" leases. Before termination the leaseholders were given the option of purchasing one-tenth of their lease land at $1.25 per acre. But the key factor, as in 1886 when the government negotiated lease changes with the cattlemen, was the unwritten promise of expanded stock water reserves. In this instance, as with the initial request for reserves, the ranchers were able to rely upon the full support of high-ranking technical experts within the Department of the Interior who were convinced that the southwest was best suited for grazing and that proper land use therefore required legislation, not to encourage potential farmers, but rather to regulate and facilitate the ranching industry already present. By keeping settlers out of the river bottoms through a system of water reservations, right of access would be assured to all stockmen, large or small. 

     The year 1896 marks something of a turning point in the history of the ranching country. Not only did the lease system upon which the cattlemen's empire had rested for a decade and a half come to an end, but there was also a change of power in Ottawa and the cattlemen were confronted with the party they had always regarded as the farmers' party. Over the next decade the political influence of the ranchers showed a steady decline. Though the first Liberal minister of the interior, Clifford Sifton, was prepared to view the southwest as a preferred grazing area and therefore to maintain the water reserve system, many of the immigrants from the United States, attracted to the North West by his department's vigorous immigration campaign, were impressed with the grazing country while traversing the region and remained to settle. 

     Sifton was succeeded in 1905 by Frank Oliver, Liberal member from Edmonton and editor of the Edmonton Bulletin. Oliver had long opposed the ranching interests in the southern half of his new province and, once in office, was determined to assist those squatters who had sought his aid over the preceding decade. Oliver spoke for those who were inclined to view the west in terms of the "mixed farm" which, it was alleged, would supply both grain and cattle and at the same time create a populous and independent citizenry that would comprise the matrix of a growing and progressive nation. Within a few months of taking office, Oliver commenced the auctioned disposal of the region's water reservations and, therefore, opened the south to general settlement. 

     The stockmen had been in retreat for some years before the weight of government had been turned directly against them. By 1900, a new frontier figure in the region intensified the struggle. The arrival, in force, of the dry-land farmer extended the competition between rancher and farmer from the creek and river bottoms to the plains beyond. For a decade the weather conspired to lend credence to the drylanders' optimism. While the two settlements at either end of the hypotenuse of the ranching triangle, Calgary and Medicine Hat, very seldom enjoyed more than ten inches annual precipitation between 1885 and 1895, the average never dropped below fifteen inches from 1896 to 1903. The voice of caution from those inhabitants of the two previous decades, coming as it did, mainly from the cattlemen, was dismissed as simply the anti-settlement propaganda of a reactionary vested interest. For the most part, ranchers were unable to remove the label fixed upon them by the settlement press as being a landed and reactionary establishment, standing in the way of settlement and "progress". The farmers, on the other hand, appealed to a morality that was much more in step with the buoyant enthusiasm of nation building that gripped the country during the first decade of the twentieth century. The tradition of small farm homes for poor men persisted among politicians who did not trouble themselves to learn that all prairie lands were not identical to the farm country of Ontario, of Manitoba, or of the Qu'Appelle Valley. "Progress" and "settlement" came to be synonymous terms. In this atmosphere, the cattlemen who brought forth proposals for restricted settlement, or who predicted drought and spoke gloomily of eventual disaster were entirely out of harmony with national feeling and, therefore, received little attention and even less understanding. 

     In the end, the ranchers' dire warnings proved not so negative, but valid, as the drought-driven refugees of the early 1920's and the 1930's bear witness. Ironically it was the faltering cattle kingdom that was first to suffer nature's wrath. The winter of 1906-07 turned out to be the worst ever experienced in the ranching country. This seemingly unending winter began with a heavy snow storm the third week of November and by December 8 temperatures ranged from -23C to -45C where they hovered almost without respite for the next two months as the indispensable chinook failed to make its accustomed appearance. Northern cattle moved south by the thousands where, if they did not perish along fence lines, they collected in the sheltered valleys of southern rivers. When the final reckoning had been made, many of the big ranches had losses in the thousands. It was alleged, for example, that the Two Bar Ranch near Gleichen lost 11,000 head from a total herd of 13,000. For many of the big ranchers and cattle companies that had managed to survive to this point, the severe winter proved the final blow. This "Carrion Spring" as Wallace Stegner has termed it, marked the end of the old order on the Canadian range. 

